{# Add the ethical ads div, when generating documentation on ReadTheDocs #}
{% if READTHEDOCS %}
<div
  id="shaphinx-sidebar-ad-placement"
  class="flat"
  data-ea-publisher="readthedocs"
  data-ea-type="readthedocs-sidebar"
  data-ea-manual="true"
></div>
{% endif %}
