<div role="search">
  <form id ="rtd-search-form" class="sidebar-search-container" action="{{ base_url }}/search.html" method="get">
    <input class="sidebar-search" type="text" name="q" placeholder="搜索文档" title="输入关键字" />
  </form>
</div>
