
<ul class="breadcrumbs">å
    <li>
      {%- block repo %}
      {% if page and page.edit_url %}
        <a class="breadcrumbs-link" href="{{ page.edit_url }}"
        {%- if config.repo_name|lower == 'github' %}
          class="icon icon-github"
        {%- elif config.repo_name|lower == 'bitbucket' %}
          class="icon icon-bitbucket"
        {%- elif config.repo_name|lower == 'gitlab' %}
          class="icon icon-gitlab"
        {% endif %}> 编辑该页面: {{ config.repo_name }}</a>
      {% endif %}
      {%- endblock %}
    </li>
  </ul>

