{% extends "base.html" %}

{% block content %}

  <h1 id="search">搜索结果</h1>

  <form id="content_search" action="search.html">
    <span role="status" aria-live="polite" class="ui-helper-hidden-accessible"></span>
    <input name="q" id="mkdocs-search-query" type="text" class="search_input search-query ui-autocomplete-input" placeholder="搜索文档" autocomplete="off" autofocus title="输入关键字">
  </form>

  <div id="mkdocs-search-results" class="search-results">
    搜索中...
  </div>

{% endblock %}
