#shaphinx-sidebar-ad-placement{padding:var(--sidebar-item-spacing-vertical) var(--sidebar-item-spacing-horizontal)}#shaphinx-sidebar-ad-placement .ethical-sidebar{border:none;box-shadow:none;background:var(--color-background-secondary)}#shaphinx-sidebar-ad-placement .ethical-sidebar:hover{background:var(--color-background-hover)}#shaphinx-sidebar-ad-placement .ethical-sidebar a{color:var(--color-foreground-primary)}#shaphinx-sidebar-ad-placement .ethical-callout a{color:var(--color-foreground-secondary)!important}:root{--tabs--label-text:var(--color-foreground-muted);--tabs--label-text--active:var(--color-brand-content);--tabs--label-text--hover:var(--color-brand-content);--tabs--label-background--active:transparent;--tabs--label-background--hover:var(--color-background-secondary);--tabs--border:var(--color-background-border)}[role=main] .container{max-width:none;padding-left:0;padding-right:0}.shadow.docutils{border:none;box-shadow:0 .2rem .5rem rgba(0,0,0,.05),0 0 .0625rem rgba(0,0,0,.1)!important}
/*# sourceMappingURL=shaphinx-extensions.css.map */
